Introduction
============

This module contains basic API for http://abclinuxu.cz.

Installation
------------
Module is hosted at `PYPI <https://pypi.python.org/pypi/abclinuxu/>`_, and can be easily 
installed using `PIP <http://en.wikipedia.org/wiki/Pip_%28package_manager%29>`_:

::

    pip install abclinuxu

Source code can be found at `GitHub <https://github.com/>`_:
https://github.com/Bystroushaak/abclinuxu

Documentation
-------------
Full module documentation is hosted at ReadTheDocs:
http://abclinuxuapi.readthedocs.org

Disclaimer
----------
The API was made by me (Bystroushaak) and it is not officially related to the
http://abclinuxu.cz project.